@@ -50,10 +50,11 @@ def merge_args(config: Config, args: Namespace):
             setattr(config, name, attr_val)
 
 
-def read_config() -> Config:
-    home = os.path.expanduser("~")
-    config_home = os.getenv("XDG_CONFIG_HOME", os.path.join(home, ".config"))
-    path = os.path.join(config_home, "ntfy-send", "config.tomla")
+def read_config(path: Optional[str] = None) -> Config:
+    if not path:
+        home = os.path.expanduser("~")
+        config_home = os.getenv("XDG_CONFIG_HOME", os.path.join(home, ".config"))
+        path = os.path.join(config_home, "ntfy-send", "config.toml")
 
     if not os.path.exists(path):
         path = os.path.join("/etc", "ntfy-send", "config.toml")
