@@ -4,6 +4,7 @@
 from typing import Any, Optional, Dict, Union
 
 import os
+import sys
 import base64
 import logging
 from urllib.parse import urljoin
@@ -30,6 +31,10 @@ def set_header(name: str, headers: Dict[str, Union[str, bytes]], val: Optional[A
 
 
 def send(args: Namespace, c: Config) -> bool:
+    if not c.server:
+        log.error("No server URL configured. Please use --server option.")
+        sys.exit(1)
+
     url = urljoin(c.server, args.topic)
 
     headers = {}
@@ -40,6 +45,9 @@ def send(args: Namespace, c: Config) -> bool:
     if args.priority:
         headers["Priority"] = str(args.priority)
 
+    if args.title:
+        headers["Title"] = str(args.title)
+
     if args.tags:
         headers["Tags"] = ",".join(args.tags)
 
